@@ -62,7 +62,7 @@ def calc_callable_loci(data, region=None, out_file=None):
     depth = {"max": max_depth * 7 if max_depth > 0 else sys.maxint - 1,
              "min": utils.get_in(data, ("config", "algorithm", "coverage_depth_min"), 4)}
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(data, out_file) as tx_out_file:
             ref_file = tz.get_in(["reference", "fasta", "base"], data)
             region_file, calc_callable = _regions_for_coverage(data, region, ref_file, tx_out_file)
             if calc_callable:
@@ -99,7 +99,7 @@ def _get_coverage_file(in_bam, ref_file, region, region_file, depth, base_file,
     """
     out_file = "%s-genomecov.bed" % utils.splitext_plus(base_file)[0]
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(data, out_file) as tx_out_file:
             bam.index(in_bam, data["config"])
             fai_file = ref.fasta_idx(ref_file, data["config"])
             sambamba = config_utils.get_program("sambamba", data["config"])
@@ -111,7 +111,7 @@ def _get_coverage_file(in_bam, ref_file, region, region_file, depth, base_file,
             do.run(cmd.format(**locals()), "bedtools genomecov: %s" % (str(region)), data)
     # Empty output file, no coverage for the whole contig
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(data, out_file) as tx_out_file:
             with open(tx_out_file, "w") as out_handle:
                 for feat in get_ref_bedtool(ref_file, data["config"], region):
                     out_handle.write("%s\t%s\t%s\t%s\n" % (feat.chrom, feat.start, feat.end, 0))
@@ -144,7 +144,7 @@ def _regions_for_coverage(data, region, ref_file, out_file):
         pybedtools.BedTool("%s\t%s\t%s\n" % (c, s, e), from_string=True).saveas(custom_file)
         return custom_file, True
     else:
-        with file_transaction(custom_file) as tx_out_file:
+        with file_transaction(data, custom_file) as tx_out_file:
             with open(tx_out_file, "w") as out_handle:
                 for feat in get_ref_bedtool(ref_file, data["config"], region):
                     out_handle.write("%s\t%s\t%s\t%s\n" % (feat.chrom, feat.start, feat.end, "NO_COVERAGE"))
@@ -158,7 +158,7 @@ def sample_callable_bed(bam_file, ref_file, config):
         callable_bed = parallel_callable_loci(bam_file, ref_file, config)
         input_regions_bed = config["algorithm"].get("variant_regions", None)
         if not utils.file_uptodate(out_file, callable_bed):
-            with file_transaction(out_file) as tx_out_file:
+            with file_transaction(config, out_file) as tx_out_file:
                 callable_regions = pybedtools.BedTool(callable_bed)
                 filter_regions = callable_regions.filter(lambda x: x.name == "CALLABLE")
                 if input_regions_bed:
@@ -359,15 +359,16 @@ def _needs_region_update(out_file, samples):
             return True
     return False
 
-def _combine_excessive_coverage(samples, ref_regions, min_n_size):
+def _combine_excessive_coverage(samples, ref_regions, min_n_size, tmp_outfile):
     """Provide a global set of regions with excessive coverage to avoid.
     """
     flag = "EXCESSIVE_COVERAGE"
     ecs = (pybedtools.BedTool(x["regions"]["callable"]).filter(lambda x: x.name == flag)
            for x in samples if "regions" in x)
-    merge_ecs = _combine_regions(ecs, ref_regions).saveas()
+    merge_ecs = _combine_regions(ecs, ref_regions).saveas("%s-ecmergeorig%s" % utils.splitext_plus(tmp_outfile))
     if len(merge_ecs) > 0:
-        return merge_ecs.merge(d=min_n_size).filter(lambda x: x.stop - x.start > min_n_size).saveas()
+        return merge_ecs.merge(d=min_n_size).filter(lambda x: x.stop - x.start > min_n_size).saveas(
+            "%s-ecmerge%s" % utils.splitext_plus(tmp_outfile))
     else:
         return merge_ecs
 
@@ -377,6 +378,7 @@ def combine_sample_regions(*samples):
     Intersects all non-callable (nblock) regions from all samples in a batch,
     producing a global set of callable regions.
     """
+    samples = [x[0] for x in samples]
     # back compatibility -- global file for entire sample set
     global_analysis_file = os.path.join(samples[0]["dirs"]["work"], "analysis_blocks.bed")
     if utils.file_exists(global_analysis_file) and not _needs_region_update(global_analysis_file, samples):
@@ -423,16 +425,20 @@ def _combine_sample_regions_batch(batch, items):
         if len(bed_regions) == 0:
             analysis_file, no_analysis_file = None, None
         else:
-            nblock_regions = reduce(operator.add, bed_regions)
-            ref_file = tz.get_in(["reference", "fasta", "base"], items[0])
-            ref_regions = get_ref_bedtool(ref_file, config)
-            min_n_size = int(config["algorithm"].get("nomap_split_size", 100))
-            ec_regions = _combine_excessive_coverage(items, ref_regions, min_n_size)
-            if len(ec_regions) > 0:
-                nblock_regions = nblock_regions.cat(ec_regions, d=min_n_size)
-            block_filter = NBlockRegionPicker(ref_regions, config)
-            final_nblock_regions = nblock_regions.filter(
-                block_filter.include_block).each(block_filter.expand_block).saveas()
-            final_regions = ref_regions.subtract(final_nblock_regions).merge(d=min_n_size)
-            _write_bed_regions(items[0], final_regions, analysis_file, no_analysis_file)
+            with file_transaction(items[0], analysis_file, no_analysis_file) as (tx_afile, tx_noafile):
+                nblock_regions = reduce(operator.add, bed_regions).saveas(
+                    "%s-nblock%s" % utils.splitext_plus(tx_afile))
+                ref_file = tz.get_in(["reference", "fasta", "base"], items[0])
+                ref_regions = get_ref_bedtool(ref_file, config)
+                min_n_size = int(config["algorithm"].get("nomap_split_size", 100))
+                ec_regions = _combine_excessive_coverage(items, ref_regions, min_n_size,
+                                                         tx_afile)
+                if len(ec_regions) > 0:
+                    nblock_regions = nblock_regions.cat(ec_regions, d=min_n_size)
+                block_filter = NBlockRegionPicker(ref_regions, config)
+                final_nblock_regions = nblock_regions.filter(
+                    block_filter.include_block).each(block_filter.expand_block).saveas(
+                        "%s-nblockfinal%s" % utils.splitext_plus(tx_afile))
+                final_regions = ref_regions.subtract(final_nblock_regions).merge(d=min_n_size)
+                _write_bed_regions(items[0], final_regions, tx_afile, tx_noafile)
     return analysis_file, no_analysis_file
