@@ -18,7 +18,7 @@ SUPPORTED_ADAPTERS = {
     "polya": ["AAAAAAAAAAAAA"],
     "nextera": ["AATGATACGGCGA", "CAAGCAGAAGACG"]}
 
-def trim_adapters(fastq_files, out_dir, lane_config):
+def trim_adapters(fastq_files, out_dir, config):
     """
     for small insert sizes, the read length can be longer than the insert
     resulting in the reverse complement of the 3' adapter being sequenced.
@@ -28,13 +28,13 @@ def trim_adapters(fastq_files, out_dir, lane_config):
     MYSEQUENCEAAAARETPADA -> MYSEQUENCEAAAA (no polyA trim)
 
     """
-    quality_format = _get_quality_format(lane_config)
-    to_trim = _get_sequences_to_trim(lane_config, SUPPORTED_ADAPTERS)
+    quality_format = _get_quality_format(config)
+    to_trim = _get_sequences_to_trim(config, SUPPORTED_ADAPTERS)
     out_files = replace_directory(append_stem(fastq_files, ".trimmed"), out_dir)
-    out_files = _cutadapt_trim(fastq_files, quality_format, to_trim, out_files)
+    out_files = _cutadapt_trim(fastq_files, quality_format, to_trim, out_files, config)
     return out_files
 
-def _cutadapt_trim(fastq_files, quality_format, adapters, out_files):
+def _cutadapt_trim(fastq_files, quality_format, adapters, out_files, config):
     """Trimming with cutadapt, using version installed with bcbio-nextgen.
 
     Uses the system executable to find the version next to our Anaconda Python.
@@ -46,10 +46,10 @@ def _cutadapt_trim(fastq_files, quality_format, adapters, out_files):
     if len(fastq_files) == 1:
         of1 = out_files[0]
         message = "Trimming %s in single end mode with cutadapt." % (fastq_files[0])
-        with file_transaction(of1) as of1_tx:
+        with file_transaction(config, of1) as of1_tx:
             do.run(cmd.format(**locals()), message)
     else:
-        with file_transaction(out_files) as tx_out_files:
+        with file_transaction(config, out_files) as tx_out_files:
             of1_tx, of2_tx = out_files
             tmp_fq1 = append_stem(of1_tx, ".tmp")
             tmp_fq2 = append_stem(of2_tx, ".tmp")
@@ -111,11 +111,11 @@ def _cutadapt_pe_nosickle(fastq_files, out_files, quality_format, base_cmd):
     second_cmd = base_cmd + " -o {of2_tx} -p {of1_tx} {tmp_fq2} {tmp_fq1}"
     return first_cmd + ";" + second_cmd + "; rm {tmp_fq1} {tmp_fq2} "
 
-def _get_sequences_to_trim(lane_config, builtin):
-    builtin_adapters = _get_builtin_adapters(lane_config, builtin)
+def _get_sequences_to_trim(config, builtin):
+    builtin_adapters = _get_builtin_adapters(config, builtin)
     polya = builtin_adapters.get("polya", [None])[0]
     # allow for trimming of custom sequences for advanced users
-    custom_trim = lane_config["algorithm"].get("custom_trim", [])
+    custom_trim = config["algorithm"].get("custom_trim", [])
     builtin_adapters = {k: v for k, v in builtin_adapters.items() if
                         k != "polya"}
     trim_sequences = custom_trim
@@ -131,10 +131,9 @@ def _get_sequences_to_trim(lane_config, builtin):
                            sequence in v]
     return trim_sequences
 
-def _get_quality_format(lane_config):
+def _get_quality_format(config):
     SUPPORTED_FORMATS = ["illumina", "standard"]
-    quality_format = lane_config["algorithm"].get("quality_format",
-                                                  "standard").lower()
+    quality_format = config["algorithm"].get("quality_format", "standard").lower()
     if quality_format not in SUPPORTED_FORMATS:
         logger.error("quality_format is set to an unsupported format. "
                      "Supported formats are %s."
@@ -142,8 +141,8 @@ def _get_quality_format(lane_config):
         exit(1)
     return quality_format
 
-def _get_builtin_adapters(lane_config, builtin):
-    chemistries = lane_config["algorithm"].get("adapters", [])
+def _get_builtin_adapters(config, builtin):
+    chemistries = config["algorithm"].get("adapters", [])
     adapters = {chemistry: builtin[chemistry] for
                 chemistry in chemistries if chemistry in builtin}
     return adapters
