@@ -11,9 +11,9 @@ import subprocess
 
 from bcbio import utils
 from bcbio.broad import picardrun
+from bcbio.distributed.transaction import tx_tmpdir
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do, programs
-from bcbio.utils import curdir_tmpdir
 
 def get_default_jvm_opts(tmp_dir=None):
     """Retrieve default JVM tuning options
@@ -261,23 +261,20 @@ class BroadRunner:
         return ["java"] + jvm_opts + get_default_jvm_opts(tmp_dir) + \
                ["-jar", gatk_jar] + [str(x) for x in params]
 
-    def run_gatk(self, params, tmp_dir=None, log_error=True, memory_retry=False,
+    def run_gatk(self, params, tmp_dir=None, log_error=True,
                  data=None, region=None, memscale=None):
-        with curdir_tmpdir({"config": self._config}) as local_tmp_dir:
+        with tx_tmpdir(self._config) as local_tmp_dir:
             if tmp_dir is None:
                 tmp_dir = local_tmp_dir
             cl = self.cl_gatk(params, tmp_dir, memscale=memscale)
             atype_index = cl.index("-T") if cl.count("-T") > 0 \
                           else cl.index("--analysis_type")
             prog = cl[atype_index + 1]
-            if memory_retry:
-                do.run_memory_retry(cl, "GATK: {0}".format(prog), data, region=region)
-            else:
-                do.run(cl, "GATK: {0}".format(prog), data, region=region,
-                       log_error=log_error)
+            do.run(cl, "GATK: {0}".format(prog), data, region=region,
+                   log_error=log_error)
 
     def run_mutect(self, params, tmp_dir=None):
-        with curdir_tmpdir({"config": self._config}) as local_tmp_dir:
+        with tx_tmpdir(self._config) as local_tmp_dir:
             if tmp_dir is None:
                 tmp_dir = local_tmp_dir
             cl = self.cl_mutect(params, tmp_dir)
