@@ -58,7 +58,10 @@ def upgrade_bcbio(args):
                                "git+%s#egg=bcbio-nextgen" % REMOTES["gitrepo"]])
         print("Upgrade of bcbio-nextgen development code complete.")
 
-    _set_matplotlib_default_backend()
+    try:
+        _set_matplotlib_default_backend()
+    except OSError:
+        pass
 
     if args.tooldir:
         with bcbio_tmpdir():
@@ -566,7 +569,7 @@ def add_subparser(subparsers):
     parser.add_argument("--genomes", help="Genomes to download",
                         action="append", default=[],
                         choices=["GRCh37", "hg19", "mm10", "mm9", "rn5", "canFam3", "dm3", "Zv9", "phix", "sacCer3",
-                                 "xenTro3", "TAIR10", "WBcel235"])
+                                 "xenTro3", "TAIR10", "WBcel235", "pseudomonas_aeruginosa_ucbpp_pa14"])
     parser.add_argument("--aligners", help="Aligner indexes to download",
                         action="append", default=[],
                         choices=["bowtie", "bowtie2", "bwa", "novoalign", "snap", "star", "ucsc"])
