@@ -5,21 +5,30 @@ functions to access the data dictionary in a clearer way
 import toolz as tz
 from bcbio.utils import file_exists
 from bcbio.log import logger
-from bcbio.pipeline import config_utils
 import sys
 
 LOOKUPS = {
     "gtf_file": {"keys": ['genome_resources', 'rnaseq', 'transcripts'],
                  "checker": file_exists},
     "work_dir": {"keys": ['dirs', 'work']},
+    "cores": {"keys": ["config", "algorithm", "num_cores"], "default": 1},
     "sample_name": {"keys": ['rgnames', 'sample']},
     "strandedness": {"keys": ['config', 'algorithm', 'strandedness'],
                      "default": "unstranded"},
     "work_bam": {"keys": ["work_bam"]},
+    "ref_file": {"keys": ["reference", "fasta", "base"]},
     "dexseq_gff": {"keys": ['genome_resources', 'rnaseq', 'dexseq']},
     "fusion_mode": {"keys": ['config', 'algorithm', 'fusion_mode']},
     "dexseq_counts": {"keys": ['dexseq_counts']},
-    "description": {"keys": ['description']}
+    "description": {"keys": ['description']},
+    "quality_format": {"keys": ['config', 'algorithm', 'quality_format'],
+                       "default": "standard"},
+    "adapters": {"keys": ['config', 'algorithm', 'adapters'],
+                 "default": []},
+    "qsig_file": {"keys": ['genome_resources', 'variation', 'qsignature'],
+                  "checker": file_exists},
+    "mixup_check": {"keys": ["config", "algorithm", "mixup_check"],
+                    "default": False}
 }
 
 def getter(keys, global_default=None):
@@ -41,4 +50,3 @@ for k, v in LOOKUPS.items():
     keys = v['keys']
     _g["get_" + k] = getter(keys, v.get('default', None))
     _g["set_" + k] = setter(keys, v.get('checker', None))
-
