@@ -12,6 +12,7 @@ import tempfile
 
 from bcbio import log, structural, utils, upload
 from bcbio.distributed import prun
+from bcbio.distributed.transaction import tx_tmpdir
 from bcbio.illumina import flowcell
 from bcbio.log import logger
 from bcbio.ngsalign import alignprep
@@ -73,7 +74,7 @@ def _run_toplevel(config, config_file, work_dir, parallel,
     samples = run_info.organize(dirs, config, run_info_yaml)
     pipelines = _pair_samples_with_pipelines(samples)
     final = []
-    with utils.curdir_tmpdir({"config": config}) as tmpdir:
+    with tx_tmpdir(config) as tmpdir:
         tempfile.tempdir = tmpdir
         for pipeline, pipeline_items in pipelines.items():
             pipeline_items = _add_provenance(pipeline_items, dirs, parallel, config)
@@ -179,7 +180,7 @@ class Variant2Pipeline(AbstractPipeline):
                 samples = disambiguate.resolve(samples, run_parallel)
             with profile.report("callable regions", dirs):
                 samples = run_parallel("postprocess_alignment", samples)
-                samples = run_parallel("combine_sample_regions", samples)
+                samples = run_parallel("combine_sample_regions", [samples])
                 samples = region.clean_sample_data(samples)
             with profile.report("coverage", dirs):
                 samples = coverage.summarize_samples(samples, run_parallel)
@@ -255,7 +256,7 @@ class StandardPipeline(AbstractPipeline):
                 samples = run_parallel("process_alignment", samples)
             with profile.report("callable regions", dirs):
                 samples = run_parallel("postprocess_alignment", samples)
-                samples = run_parallel("combine_sample_regions", samples)
+                samples = run_parallel("combine_sample_regions", [samples])
                 samples = region.clean_sample_data(samples)
         ## Quality control
         with prun.start(_wres(parallel, ["fastqc", "bamtools", "samtools", "qsignature", "kraken"]),
