@@ -169,7 +169,7 @@ ALGORITHM_KEYS = set(["platform", "aligner", "bam_clean", "bam_sort",
                       "align_split_size", "quality_bin",
                       "quality_format", "write_summary",
                       "merge_bamprep", "coverage",
-                      "coverage_interval", "ploidy",
+                      "coverage_interval", "ploidy", "indelcaller",
                       "variantcaller", "jointcaller", "variant_regions", "effects",
                       "mark_duplicates", "svcaller", "svvalidate", "recalibrate",
                       "realign", "phasing", "validate",
