@@ -17,9 +17,9 @@ def bcbio_run(data):
     bam_file = dd.get_work_bam(data)
     dexseq_gff = dd.get_dexseq_gff(data)
     stranded = dd.get_strandedness(data)
-    return run_count(bam_file, dexseq_gff, stranded, out_file)
+    return run_count(bam_file, dexseq_gff, stranded, out_file, data)
 
-def run_count(bam_file, dexseq_gff, stranded, out_file):
+def run_count(bam_file, dexseq_gff, stranded, out_file, data):
     """
     run dexseq_count on a BAM file
     """
@@ -47,7 +47,7 @@ def run_count(bam_file, dexseq_gff, stranded, out_file):
     cmd = ("python {dexseq_count} -f bam -r {sort_flag} -p {paired_flag} "
            "-s {strand_flag} {dexseq_gff} {bam_file} {tx_out_file}")
     message = "Counting exon-level counts with %s and %s." % (bam_file, dexseq_gff)
-    with file_transaction(out_file) as tx_out_file:
+    with file_transaction(data, out_file) as tx_out_file:
         do.run(cmd.format(**locals()), message)
     return out_file
 
