@@ -174,31 +174,6 @@ def safe_makedir(dname):
             time.sleep(2)
     return dname
 
-@contextlib.contextmanager
-def curdir_tmpdir(data=None, base_dir=None, remove=True):
-    """Context manager to create and remove a temporary directory.
-
-    This can also handle a configured temporary directory to use.
-    """
-    config_tmpdir = get_in(data, ("config", "resources", "tmp", "dir")) if data else None
-    if config_tmpdir:
-        tmp_dir_base = os.path.join(config_tmpdir, "bcbiotmp")
-    elif base_dir is not None:
-        tmp_dir_base = os.path.join(base_dir, "bcbiotmp")
-    else:
-        tmp_dir_base = os.path.join(os.getcwd(), "tmp")
-    safe_makedir(tmp_dir_base)
-    tmp_dir = tempfile.mkdtemp(dir=tmp_dir_base)
-    safe_makedir(tmp_dir)
-    try:
-        yield tmp_dir
-    finally:
-        if remove:
-            try:
-                shutil.rmtree(tmp_dir)
-            except:
-                pass
-
 @contextlib.contextmanager
 def chdir(new_dir):
     """Context manager to temporarily change to a new directory.
@@ -236,13 +211,19 @@ def file_exists_or_remote(fname):
 def file_exists(fname):
     """Check if a file exists and is non-empty.
     """
-    return fname and os.path.exists(fname) and os.path.getsize(fname) > 0
+    try:
+        return fname and os.path.exists(fname) and os.path.getsize(fname) > 0
+    except OSError:
+        return False
 
 def file_uptodate(fname, cmp_fname):
     """Check if a file exists, is non-empty and is more recent than cmp_fname.
     """
-    return (file_exists(fname) and file_exists(cmp_fname) and
-            os.path.getmtime(fname) >= os.path.getmtime(cmp_fname))
+    try:
+        return (file_exists(fname) and file_exists(cmp_fname) and
+                os.path.getmtime(fname) >= os.path.getmtime(cmp_fname))
+    except OSError:
+        return False
 
 def create_dirs(config, names=None):
     if names is None:
@@ -397,7 +378,7 @@ def merge_config_files(fnames):
     for fname in fnames[1:]:
         cur = _load_yaml(fname)
         for k, v in cur.iteritems():
-            if out.has_key(k) and isinstance(out[k], dict):
+            if k in out and isinstance(out[k], dict):
                 out[k].update(v)
             else:
                 out[k] = v
