@@ -31,7 +31,7 @@ def annotate_nongatk_vcf(orig_file, bam_files, dbsnp_file, ref_file, config):
     else:
         out_file = "%s-gatkann%s" % utils.splitext_plus(orig_file)
         if not utils.file_exists(out_file):
-            with file_transaction(out_file) as tx_out_file:
+            with file_transaction(config, out_file) as tx_out_file:
                 # Avoid issues with incorrectly created empty GATK index files.
                 # Occurs when GATK cannot lock shared dbSNP database on previous run
                 idx_file = orig_file + ".idx"
@@ -64,6 +64,6 @@ def annotate_nongatk_vcf(orig_file, bam_files, dbsnp_file, ref_file, config):
                     params.pop(ind_to_rem)
                 params.extend(["-U", "ALL"])
                 broad_runner = broad.runner_from_config(config)
-                broad_runner.run_gatk(params, memory_retry=True)
+                broad_runner.run_gatk(params)
         vcfutils.bgzip_and_index(out_file, config)
         return out_file
