@@ -16,7 +16,7 @@ from bcbio.distributed.transaction import file_transaction
 from bcbio.pipeline import config_utils
 from bcbio.pipeline.shared import subset_variant_regions
 from bcbio.provenance import do
-from bcbio.variation import annotation, bedutils, ploidy
+from bcbio.variation import annotation, bedutils, ploidy, vcfutils
 from bcbio.variation.vcfutils import (get_paired_bams, is_paired_analysis,
                                       bgzip_and_index, move_vcf)
 
@@ -47,11 +47,6 @@ def _freebayes_options_from_config(items, config, out_file, region=None):
     resources = config_utils.get_resources("freebayes", config)
     if resources.get("options"):
         opts += resources["options"]
-    if "--min-alternate-fraction" not in " ".join(opts) and "-F" not in " ".join(opts):
-        # add minimum reportable allele frequency, for which FreeBayes defaults to 20
-        min_af = float(utils.get_in(config, ("algorithm",
-                                             "min_allele_fraction"), 20)) / 100.0
-        opts += ["--min-alternate-fraction", str(min_af)]
     return opts
 
 def run_freebayes(align_bams, items, ref_file, assoc_files, region=None,
@@ -62,6 +57,7 @@ def run_freebayes(align_bams, items, ref_file, assoc_files, region=None,
         call_file = _run_freebayes_paired(align_bams, items, ref_file,
                                           assoc_files, region, out_file)
     else:
+        vcfutils.check_paired_problems(items)
         call_file = _run_freebayes_caller(align_bams, items, ref_file,
                                           assoc_files, region, out_file)
 
@@ -79,7 +75,7 @@ def _run_freebayes_caller(align_bams, items, ref_file, assoc_files,
     if out_file is None:
         out_file = "%s-variants.vcf.gz" % os.path.splitext(align_bams[0])[0]
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(items[0], out_file) as tx_out_file:
             for align_bam in align_bams:
                 bam.index(align_bam, config)
             freebayes = config_utils.get_program("freebayes", config)
@@ -111,7 +107,7 @@ def _run_freebayes_paired(align_bams, items, ref_file, assoc_files,
     if out_file is None:
         out_file = "%s-paired-variants.vcf.gz" % os.path.splitext(align_bams[0])[0]
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(items[0], out_file) as tx_out_file:
             paired = get_paired_bams(align_bams, items)
             if not paired.normal_bam:
                 return _run_freebayes_caller(align_bams, items, ref_file,
@@ -124,7 +120,6 @@ def _run_freebayes_paired(align_bams, items, ref_file, assoc_files,
             vcfstreamsort = config_utils.get_program("vcfstreamsort", config)
             freebayes = config_utils.get_program("freebayes", config)
             opts = " ".join(_freebayes_options_from_config(items, config, out_file, region))
-            opts += " -f {}".format(ref_file)
             if "--min-alternate-fraction" not in opts and "-F" not in opts:
                 # add minimum reportable allele frequency
                 # FreeBayes defaults to 20%, but use 10% by default for the
@@ -132,18 +127,21 @@ def _run_freebayes_paired(align_bams, items, ref_file, assoc_files,
                 min_af = float(utils.get_in(paired.tumor_config, ("algorithm",
                                                                   "min_allele_fraction"), 10)) / 100.0
                 opts += " --min-alternate-fraction %s" % min_af
+            opts += " --min-repeat-entropy 1 --experimental-gls"
+            # Recommended settings for cancer calling
+            # https://groups.google.com/d/msg/freebayes/dTWBtLyM4Vs/HAK_ZhJHguMJ
+            opts += " --pooled-discrete --genotype-qualities --report-genotype-likelihood-max"
             # NOTE: The first sample name in the vcfsamplediff call is
             # the one supposed to be the *germline* one
-
             # NOTE: -s in vcfsamplediff (strict checking: i.e., require no
             # reads in the germline to call somatic) is not used as it is
             # too stringent
             compress_cmd = "| bgzip -c" if out_file.endswith("gz") else ""
-            cl = ("{freebayes} --pooled-discrete --genotype-qualities "
-                  "{opts} {paired.tumor_bam} {paired.normal_bam} "
-                  "| {vcffilter} -f 'QUAL > 1' -s "
-                  "| {vcfsamplediff} VT {paired.normal_name} {paired.tumor_name} - "
+            cl = ("{freebayes} -f {ref_file} {opts} "
+                  "{paired.tumor_bam} {paired.normal_bam} "
+                  "| {vcffilter} -f 'QUAL > 5' -s "
                   "| {vcfallelicprimitives} | {vcfstreamsort} "
+                  "| {vcfsamplediff} VT {paired.normal_name} {paired.tumor_name} - "
                   "{compress_cmd} > {tx_out_file}")
             bam.index(paired.tumor_bam, config)
             bam.index(paired.normal_bam, config)
@@ -178,7 +176,7 @@ def _clean_freebayes_output(line):
             return line
     return None
 
-def clean_vcf_output(orig_file, clean_fn, name="clean"):
+def clean_vcf_output(orig_file, clean_fn, config, name="clean"):
     """Provide framework to clean a file in-place, with the specified clean
     function.
     """
@@ -186,7 +184,7 @@ def clean_vcf_output(orig_file, clean_fn, name="clean"):
     out_file = "{0}-{1}{2}".format(base, name, ext)
     if not utils.file_exists(out_file):
         with open(orig_file) as in_handle:
-            with file_transaction(out_file) as tx_out_file:
+            with file_transaction(config, out_file) as tx_out_file:
                 with open(tx_out_file, "w") as out_handle:
                     for line in in_handle:
                         update_line = clean_fn(line)
@@ -222,7 +220,7 @@ def fix_somatic_calls(in_file, config):
         for ext in [".gz", ".gz.tbi"]:
             if os.path.exists(out_file + ext):
                 os.remove(out_file + ext)
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             with open(tx_out_file, "wb") as handle:
                 writer = vcf.VCFWriter(handle, template=reader)
                 for record in reader:
