@@ -107,20 +107,21 @@ def mutect_caller(align_bams, items, ref_file, assoc_files, region=None,
               not all(has_aligned_reads(x, region) for x in align_bams)):
                 vcfutils.write_empty_vcf(out_file)
                 return
-        with file_transaction(out_file_mutect) as tx_out_file:
+        with file_transaction(config, out_file_mutect) as tx_out_file:
             # Rationale: MuTect writes another table to stdout, which we don't need
             params += ["--vcf", tx_out_file, "-o", os.devnull]
             broad_runner.run_mutect(params)
-        _rename_allelic_fraction_field(out_file_mutect,config)
-        disable_SID = True # SID isn't great, so use Scalpel instead
-        if "appistry" not in broad_runner.get_mutect_version() or disable_SID:
+        _rename_allelic_fraction_field(out_file_mutect, config)
+        indelcaller = vcfutils.get_indelcaller(base_config)
+        if "scalpel" in indelcaller.lower():
             # Scalpel InDels
             is_paired = "-I:normal" in params
             out_file_indels = (out_file.replace(".vcf", "-somaticIndels.vcf")
                                if "vcf" in out_file else out_file + "-somaticIndels.vcf")
             if scalpel.is_installed(items[0]["config"]):
-                with file_transaction(out_file_indels) as tx_out_file2:
+                with file_transaction(config, out_file_indels) as tx_out_file2:
                     if not is_paired:
+                        vcfutils.check_paired_problems(items)
                         scalpel._run_scalpel_caller(align_bams, items, ref_file, assoc_files,
                                                     region=region, out_file=tx_out_file2)
                     else:
@@ -133,13 +134,14 @@ def mutect_caller(align_bams, items, ref_file, assoc_files, region=None,
                                                           region=region)
             else:
                 utils.symlink_plus(out_file_mutect, out_file)
-        else:
-            # SomaticIndelDetector modifications
+        elif (("somaticindeldetector" in indelcaller.lower() or "sid" in indelcaller.lower())
+              and "appistry" in broad_runner.get_mutect_version()):
+            # SomaticIndelDetector InDels
             out_file_indels = (out_file.replace(".vcf", "-somaticIndels.vcf")
                                if "vcf" in out_file else out_file + "-somaticIndels.vcf")
             params_indels = _SID_call_prep(align_bams, items, ref_file, assoc_files,
                                            region, out_file_indels)
-            with file_transaction(out_file_indels) as tx_out_file:
+            with file_transaction(config, out_file_indels) as tx_out_file:
                 params_indels += ["-o", tx_out_file]
                 broad_runner.run_mutect(params_indels)
             out_file = vcfutils.combine_variant_files(orig_files=[out_file_mutect, out_file_indels],
@@ -147,6 +149,8 @@ def mutect_caller(align_bams, items, ref_file, assoc_files, region=None,
                                                       ref_file=items[0]["sam_ref"],
                                                       config=items[0]["config"],
                                                       region=region)
+        else:
+            utils.symlink_plus(out_file_mutect, out_file)
     return out_file
 
 def _SID_call_prep(align_bams, items, ref_file, assoc_files, region=None, out_file=None):
@@ -182,27 +186,23 @@ def _SID_call_prep(align_bams, items, ref_file, assoc_files, region=None, out_fi
                    "INTERSECTION"]
     return params
 
-
-def _rename_allelic_fraction_field(orig_file,config):
+def _rename_allelic_fraction_field(orig_file, config):
     """Rename allelic fraction field in mutect output
        from FA to FREQ to standarize with other tools
     """
-    tmp_file = orig_file.replace(".vcf.gz","-fix.vcf")
-    with file_transaction(tmp_file) as tx_in_file:       
-        with open(tx_in_file,'w') as out_handle:
+    tmp_file = orig_file.replace(".vcf.gz", "-fix.vcf")
+    with file_transaction(config, tmp_file) as tx_in_file:
+        with open(tx_in_file, 'w') as out_handle:
             with open_gzipsafe(orig_file) as handle:
                 for line in handle:
                     if line.startswith("##FORMAT=<ID=FA"):
-                        line = line.replace("=FA","=FREQ")
+                        line = line.replace("=FA", "=FREQ")
                     if not line.startswith("#"):
-                        line = line.replace("FA","FREQ")
+                        line = line.replace("FA", "FREQ")
                     out_handle.write(line)
-    out_file = orig_file.replace(".gz","")
+    out_file = orig_file.replace(".gz", "")
     remove_safe(orig_file)
-    shutil.move(tmp_file, out_file )
+    shutil.move(tmp_file, out_file)
     with open(tmp_file, "w") as out_handle:
         out_handle.write("Moved to {0}".format(out_file))
     out_file = bgzip_and_index(out_file, config)
-
-
-
