@@ -11,8 +11,8 @@ import toolz as tz
 
 from bcbio import bam, broad
 from bcbio.log import logger
-from bcbio.utils import curdir_tmpdir, file_exists
-from bcbio.distributed.transaction import file_transaction
+from bcbio.utils import file_exists
+from bcbio.distributed.transaction import file_transaction, tx_tmpdir
 from bcbio.variation.realign import has_aligned_reads
 
 # ## GATK recalibration
@@ -59,8 +59,8 @@ def _gatk_base_recalibrator(broad_runner, dup_align_bam, ref_file, platform,
     out_file = "%s.grp" % os.path.splitext(dup_align_bam)[0]
     if not file_exists(out_file):
         if has_aligned_reads(dup_align_bam, intervals):
-            with curdir_tmpdir(data) as tmp_dir:
-                with file_transaction(out_file) as tx_out_file:
+            with tx_tmpdir(data) as tmp_dir:
+                with file_transaction(data, out_file) as tx_out_file:
                     params = ["-T", "BaseRecalibrator",
                               "-o", tx_out_file,
                               "-I", dup_align_bam,
