@@ -1,10 +1,12 @@
-"""Variant calling using samtools mpileup and bcftools.
+"""Variant calling using samtools 1.0 mpileup and bcftools.
 
-http://samtools.sourceforge.net/mpileup.shtml
+http://www.htslib.org/workflow/#mapping_to_variant
 """
 import os
 from distutils.version import LooseVersion
 
+import toolz as tz
+
 from bcbio import bam
 from bcbio.utils import file_exists
 from bcbio.distributed.transaction import file_transaction
@@ -12,7 +14,7 @@ from bcbio.log import logger
 from bcbio.pipeline import config_utils
 from bcbio.pipeline.shared import subset_variant_regions
 from bcbio.provenance import do, programs
-from bcbio.variation import annotation, bamprep, realign, vcfutils
+from bcbio.variation import annotation, bamprep, bedutils, vcfutils
 
 def shared_variantcall(call_fn, name, align_bams, ref_file, items,
                        assoc_files, region=None, out_file=None):
@@ -29,15 +31,18 @@ def shared_variantcall(call_fn, name, align_bams, ref_file, items,
               name=name, region=region, fname=os.path.basename(align_bams[0])))
         for x in align_bams:
             bam.index(x, config)
-        variant_regions = config["algorithm"].get("variant_regions", None)
+        variant_regions = bedutils.merge_overlaps(tz.get_in(["config", "algorithm", "variant_regions"], items[0]),
+                                                  items[0])
         target_regions = subset_variant_regions(variant_regions, region, out_file)
         if (variant_regions is not None and isinstance(target_regions, basestring)
               and not os.path.isfile(target_regions)):
             vcfutils.write_empty_vcf(out_file, config)
         else:
-            with file_transaction(out_file) as tx_out_file:
+            with file_transaction(config, out_file) as tx_out_file:
                 call_fn(align_bams, ref_file, items, target_regions,
                         tx_out_file)
+    if out_file.endswith(".gz"):
+        out_file = vcfutils.bgzip_and_index(out_file, config)
     ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams, assoc_files.get("dbsnp"),
                                                ref_file, config)
     return ann_file
@@ -49,13 +54,13 @@ def run_samtools(align_bams, items, ref_file, assoc_files, region=None,
     return shared_variantcall(_call_variants_samtools, "samtools", align_bams, ref_file,
                               items, assoc_files, region, out_file)
 
-def prep_mpileup(align_bams, ref_file, max_read_depth, config,
+def prep_mpileup(align_bams, ref_file, config, max_read_depth=None,
                  target_regions=None, want_bcf=True):
-    cl = [config_utils.get_program("samtools", config), "mpileup",
-          "-f", ref_file, "-d", str(max_read_depth), "-L", str(max_read_depth),
-          "-m", "3", "-F", "0.0002"]
+    cl = [config_utils.get_program("samtools", config), "mpileup", "-f", ref_file]
+    if max_read_depth:
+        cl += ["-d", str(max_read_depth), "-L", str(max_read_depth)]
     if want_bcf:
-        cl += ["-D", "-S", "-u"]
+        cl += ["-t", "DP", "-u", "-g"]
     if target_regions:
         str_regions = bamprep.region_to_gatk(target_regions)
         if os.path.isfile(str_regions):
@@ -65,37 +70,26 @@ def prep_mpileup(align_bams, ref_file, max_read_depth, config,
     cl += align_bams
     return " ".join(cl)
 
-def _call_variants_samtools(align_bams, ref_file, items, target_regions, out_file):
+def _call_variants_samtools(align_bams, ref_file, items, target_regions, tx_out_file):
     """Call variants with samtools in target_regions.
 
-    Works around a GATK VCF compatibility issue in samtools 0.20 by removing extra
-    Version information from VCF header lines.
+    Works around a GATK VCF 4.2 compatibility issue in samtools 1.0
+    by removing addition 4.2-only isms from VCF header lines.
     """
     config = items[0]["config"]
-
-    max_read_depth = "1000"
-    mpileup = prep_mpileup(align_bams, ref_file, max_read_depth, config,
-                           target_regions=target_regions)
+    mpileup = prep_mpileup(align_bams, ref_file, config,
+                           target_regions=target_regions, want_bcf=True)
     bcftools = config_utils.get_program("bcftools", config)
     bcftools_version = programs.get_version("bcftools", config=config)
     samtools_version = programs.get_version("samtools", config=config)
-    if LooseVersion(bcftools_version) > LooseVersion("0.1.19"):
-        if LooseVersion(samtools_version) <= LooseVersion("0.1.19"):
-            raise ValueError("samtools calling not supported with 0.1.19 samtools and 0.20 bcftools")
-        bcftools_opts = "call -v -c"
-    else:
-        bcftools_opts = "view -v -c -g"
-    compress_cmd = "| bgzip -c" if out_file.endswith("gz") else ""
-    vcfutils = config_utils.get_program("vcfutils.pl", config)
-    # XXX Check if we need this when supporting samtools 0.2.0 calling.
-    # 0.1.9 fails on regions without reads.
-    if not any(realign.has_aligned_reads(x, target_regions) for x in align_bams):
-        vcfutils.write_empty_vcf(out_file, config)
-    else:
-        cmd = ("{mpileup} "
-               "| {bcftools} {bcftools_opts} - "
-               "| {vcfutils} varFilter -D {max_read_depth} "
-               "| sed 's/,Version=3>/>/'"
-               "{compress_cmd} > {out_file}")
-        logger.info(cmd.format(**locals()))
-        do.run(cmd.format(**locals()), "Variant calling with samtools", {})
+    if LooseVersion(samtools_version) <= LooseVersion("0.1.19"):
+        raise ValueError("samtools calling not supported with pre-1.0 samtools")
+    bcftools_opts = "call -v -m"
+    compress_cmd = "| bgzip -c" if tx_out_file.endswith(".gz") else ""
+    cmd = ("{mpileup} "
+           "| {bcftools} {bcftools_opts} - "
+           "| {bcftools} norm -f {ref_file} -m '-both' - "
+           "| sed 's/,Version=3>/>/'"
+           "| sed 's/Number=R/Number=./'"
+           "{compress_cmd} > {tx_out_file}")
+    do.run(cmd.format(**locals()), "Variant calling with samtools", items[0])
