@@ -8,6 +8,10 @@ import os
 
 import numpy as np
 try:
+    import matplotlib
+    matplotlib.use('Agg', force=True)
+    import matplotlib.pyplot as plt
+    plt.ioff()
     import prettyplotlib as ppl
     import pandas as pd
 except ImportError:
