@@ -10,7 +10,7 @@ import os
 import shutil
 
 from bcbio import broad, utils
-from bcbio.distributed.transaction import file_transaction
+from bcbio.distributed.transaction import file_transaction, tx_tmpdir
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do, programs
 from bcbio.utils import file_exists, append_stem
@@ -30,6 +30,7 @@ def run_varscan(align_bams, items, ref_file, assoc_files,
                                                 align_bams, ref_file, items,
                                                 assoc_files, region, out_file)
     else:
+        vcfutils.check_paired_problems(items)
         call_file = samtools.shared_variantcall(_varscan_work, "varscan",
                                                 align_bams, ref_file,
                                                 items, assoc_files,
@@ -84,9 +85,9 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
         for fname, mpext in [(paired.normal_bam, "normal"), (paired.tumor_bam, "tumor")]:
             mpfile = "%s-%s.mpileup" % (base, mpext)
             cleanup_files.append(mpfile)
-            with file_transaction(mpfile) as mpfile_tx:
+            with file_transaction(config, mpfile) as mpfile_tx:
                 mpileup = samtools.prep_mpileup([fname], ref_file,
-                                                max_read_depth, config,
+                                                config, max_read_depth,
                                                 target_regions=target_regions,
                                                 want_bcf=False)
                 cmd = "{mpileup} > {mpfile_tx}"
@@ -109,32 +110,38 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
         snp_file = base + ".snp.vcf"
         cleanup_files.append(indel_file)
         cleanup_files.append(snp_file)
-        with file_transaction(indel_file, snp_file) as (tx_indel, tx_snp):
-            with utils.curdir_tmpdir(items[0]) as tmp_dir:
+        with file_transaction(config, indel_file, snp_file) as (tx_indel, tx_snp):
+            with tx_tmpdir(items[0]) as tmp_dir:
                 jvm_opts = _get_varscan_opts(config, tmp_dir)
+                fix_ambig = vcfutils.fix_ambiguous_cl()
+                tx_snp_in = "%s-orig" % os.path.splitext(tx_snp)[0]
+                tx_indel_in = "%s-orig" % os.path.splitext(tx_indel)[0]
                 varscan_cmd = ("java {jvm_opts} -jar {varscan_jar} somatic"
-                       " {normal_tmp_mpileup} {tumor_tmp_mpileup} {base}"
-                       " --output-vcf --min-coverage 5 --p-value 0.98 "
-                       "--strand-filter 1 ")
+                               " {normal_tmp_mpileup} {tumor_tmp_mpileup} "
+                               "--output-snp {tx_snp_in} --output-indel {tx_indel_in} "
+                               " --output-vcf --min-coverage 5 --p-value 0.98 "
+                               "--strand-filter 1 ")
                 # add minimum AF
                 if "--min-var-freq" not in varscan_cmd:
                     min_af = float(utils.get_in(paired.tumor_config, ("algorithm",
                                                                       "min_allele_fraction"),10)) / 100.0
                     varscan_cmd += "--min-var-freq {min_af} "
                 do.run(varscan_cmd.format(**locals()), "Varscan", None, None)
+                for orig_fname, fname in [(tx_snp_in, tx_snp), (tx_indel_in, tx_indel)]:
+                    cmd = "vcfuniqalleles {orig_fname}.vcf | {fix_ambig} > {fname}"
+                    do.run(cmd.format(**locals()), "Varscan paired fix")
 
         # VarScan files need to be corrected to match the VCF specification
         # We do this before combining them otherwise merging may fail
         # if there are invalid records
-
         to_combine = []
         if do.file_exists(snp_file):
             to_combine.append(snp_file)
-            _fix_varscan_vcf(snp_file, paired.normal_name, paired.tumor_name)
+            _fix_varscan_vcf(snp_file, paired.normal_name, paired.tumor_name, config)
 
         if do.file_exists(indel_file):
             to_combine.append(indel_file)
-            _fix_varscan_vcf(indel_file, paired.normal_name, paired.tumor_name)
+            _fix_varscan_vcf(indel_file, paired.normal_name, paired.tumor_name, config)
 
         if not to_combine:
             write_empty_vcf(orig_out_file, config)
@@ -159,7 +166,7 @@ def _varscan_paired(align_bams, ref_file, items, target_regions, out_file):
 
         _add_reject_flag(out_file, config)
 
-def _fix_varscan_vcf(orig_file, normal_name, tumor_name):
+def _fix_varscan_vcf(orig_file, normal_name, tumor_name, config):
     """Fixes issues with the standard VarScan VCF output.
 
     - Remap sample names back to those defined in the input BAM file.
@@ -170,13 +177,12 @@ def _fix_varscan_vcf(orig_file, normal_name, tumor_name):
     if not file_exists(tmp_file):
         shutil.move(orig_file, tmp_file)
 
-        with file_transaction(orig_file) as tx_out_file:
+        with file_transaction(config, orig_file) as tx_out_file:
             with open(tmp_file) as in_handle:
                 with open(tx_out_file, "w") as out_handle:
 
                     for line in in_handle:
-                        line = _clean_varscan_line(_fix_varscan_output(line, normal_name,
-                                                                       tumor_name))
+                        line = _clean_varscan_line(_fix_varscan_output(line, normal_name, tumor_name))
                         if not line:
                             continue
                         out_handle.write(line)
@@ -198,7 +204,7 @@ def _add_reject_flag(in_file, config):
         reader = vcf.VCFReader(filename=in_file)
         # Add info to the header of the reader
         reader.filters["REJECT"] = reject_filter
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             with open(tx_out_file, "wb") as handle:
                 writer = vcf.VCFWriter(handle, template=reader)
                 for record in reader:
@@ -342,7 +348,7 @@ def _varscan_work(align_bams, ref_file, items, target_regions, out_file):
     varscan_jar = config_utils.get_jar("VarScan",
                                        config_utils.get_program("varscan", config, "dir"))
     sample_list = _create_sample_list(align_bams, out_file)
-    mpileup = samtools.prep_mpileup(align_bams, ref_file, max_read_depth, config,
+    mpileup = samtools.prep_mpileup(align_bams, ref_file, config, max_read_depth,
                                     target_regions=target_regions, want_bcf=False)
     # VarScan fails to generate a header on files that start with
     # zerocoverage calls; strip these with grep, we're not going to
@@ -350,18 +356,19 @@ def _varscan_work(align_bams, ref_file, items, target_regions, out_file):
     remove_zerocoverage = "grep -v -P '\t0\t\t$'"
     # write a temporary mpileup file so we can check if empty
     mpfile = "%s.mpileup" % os.path.splitext(out_file)[0]
-    with file_transaction(mpfile) as mpfile_tx:
+    with file_transaction(config, mpfile) as mpfile_tx:
         cmd = ("{mpileup} | {remove_zerocoverage} > {mpfile_tx}")
         do.run(cmd.format(**locals()), "mpileup for Varscan")
     if os.path.getsize(mpfile) == 0:
         write_empty_vcf(out_file)
     else:
-        with utils.curdir_tmpdir(items[0]) as tmp_dir:
+        with tx_tmpdir(items[0]) as tmp_dir:
             jvm_opts = _get_varscan_opts(config, tmp_dir)
+            fix_ambig = vcfutils.fix_ambiguous_cl()
             cmd = ("cat {mpfile} "
                    "| java {jvm_opts} -jar {varscan_jar} mpileup2cns --min-coverage 5 --p-value 0.98 "
                    "  --vcf-sample-list {sample_list} --output-vcf --variants "
-                   "> {out_file}")
+                   "| {fix_ambig} | vcfuniqalleles > {out_file}")
             do.run(cmd.format(**locals()), "Varscan", None,
                    [do.file_exists(out_file)])
     os.remove(sample_list)
@@ -371,7 +378,7 @@ def _varscan_work(align_bams, ref_file, items, target_regions, out_file):
     if os.path.getsize(out_file) == 0:
         write_empty_vcf(out_file)
     else:
-        freebayes.clean_vcf_output(out_file, _clean_varscan_line)
+        freebayes.clean_vcf_output(out_file, _clean_varscan_line, config)
 
     if orig_out_file.endswith(".gz"):
         vcfutils.bgzip_and_index(out_file, config)
