@@ -8,7 +8,6 @@ import itertools
 import os
 import shutil
 import subprocess
-import vcf
 
 import toolz as tz
 
@@ -18,6 +17,7 @@ from bcbio.distributed.multi import run_multicore, zeromq_aware_logging
 from bcbio.distributed.split import parallel_split_combine
 from bcbio.distributed.transaction import file_transaction
 from bcbio.pipeline import config_utils, shared, tools
+from bcbio.pipeline import datadict as dd
 from bcbio.provenance import do
 from bcbio.variation import bamprep
 
@@ -52,6 +52,15 @@ def get_paired_bams(align_bams, items):
         return PairedData(tumor_bam, tumor_name, normal_bam,
                           normal_name, normal_panel, tumor_config)
 
+def check_paired_problems(items):
+    """Check for incorrectly paired tumor/normal samples
+    """
+    if any(tz.get_in(["metadata", "phenotype"], data, "").lower() == "normal"
+           for data in items):
+        raise ValueError("Found normal sample without tumor in batch %s: %s" %
+                         (tz.get_in(["metadata", "batch"], items[0]),
+                          [dd.get_sample_name(data) for data in items]))
+
 def get_paired_phenotype(data):
     """Retrieve the phenotype for a paired tumor/normal analysis.
     """
@@ -61,6 +70,25 @@ def get_paired_phenotype(data):
 
 # ## General utilities
 
+def fix_ambiguous_cl():
+    """awk command to replace non-N ambiguous REF bases with N.
+
+    Some callers include these if present in the reference genome but GATK does
+    not like them.
+    """
+    return r"""awk -F$'\t' -v OFS='\t' '{if ($0 !~ /^#/) gsub(/[KMRYSWBVHDX]/, "N", $4) } {print}'"""
+
+def get_indelcaller(d_or_c):
+    """Retrieve string for indelcaller to use, or empty string if not specified.
+    """
+    config = d_or_c if isinstance(d_or_c, dict) and "config" in d_or_c else d_or_c
+    indelcaller = config["algorithm"].get("indelcaller", "")
+    if not indelcaller:
+        indelcaller = ""
+    if isinstance(indelcaller, (list, tuple)):
+        indelcaller = indelcaller[0] if (len(indelcaller) > 0) else ""
+    return indelcaller
+
 def write_empty_vcf(out_file, config=None, samples=None):
     needs_bgzip = False
     if out_file.endswith(".vcf.gz"):
@@ -84,7 +112,7 @@ def split_snps_indels(orig_file, ref_file, config):
     for out_file, select_arg in [(snp_file, "--types snps"),
                                  (indel_file, "--exclude-types snps")]:
         if not utils.file_exists(out_file):
-            with file_transaction(out_file) as tx_out_file:
+            with file_transaction(config, out_file) as tx_out_file:
                 bcftools = config_utils.get_program("bcftools", config)
                 output_type = "z" if out_file.endswith(".gz") else "v"
                 cmd = "{bcftools} view -O {output_type} {orig_file} {select_arg} > {tx_out_file}"
@@ -123,11 +151,11 @@ def exclude_samples(in_file, out_file, to_exclude, ref_file, config, filters=Non
     if len(exclude) == 0:
         out_file = in_file
     elif not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             bcftools = config_utils.get_program("bcftools", config)
             output_type = "z" if out_file.endswith(".gz") else "v"
             include_str = ",".join(include)
-            filter_str = "-f %s" % filters if filters is not None else "" # filters could be e.g. 'PASS,.'
+            filter_str = "-f %s" % filters if filters is not None else ""  # filters could be e.g. 'PASS,.'
             cmd = "{bcftools} view -O {output_type} -s {include_str} {filter_str} {in_file} > {tx_out_file}"
             do.run(cmd.format(**locals()), "Exclude samples: {}".format(to_exclude))
     return out_file
@@ -136,12 +164,12 @@ def select_sample(in_file, sample, out_file, config, filters=None):
     """Select a single sample from the supplied multisample VCF file.
     """
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             if in_file.endswith(".gz"):
                 bgzip_and_index(in_file, config)
             bcftools = config_utils.get_program("bcftools", config)
             output_type = "z" if out_file.endswith(".gz") else "v"
-            filter_str = "-f %s" % filters if filters is not None else "" # filters could be e.g. 'PASS,.'
+            filter_str = "-f %s" % filters if filters is not None else ""  # filters could be e.g. 'PASS,.'
             cmd = "{bcftools} view -O {output_type} {filter_str} {in_file} -s {sample} > {tx_out_file}"
             do.run(cmd.format(**locals()), "Select sample: %s" % sample)
     if out_file.endswith(".gz"):
@@ -180,7 +208,7 @@ def _do_merge(orig_files, out_file, config, region):
     """Do the actual work of merging with bcftools merge.
     """
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             _check_samples_nodups(orig_files)
             prep_files = run_multicore(p_bgzip_and_index, [[x, config] for x in orig_files], config)
             input_vcf_file = "%s-files.txt" % utils.splitext_plus(out_file)[0]
@@ -214,6 +242,7 @@ def _sort_by_region(fnames, regions, ref_file, config):
     for i, sq in enumerate(ref.file_contigs(ref_file, config)):
         contig_order[sq.name] = i
     sitems = []
+    assert len(regions) == len(fnames), (regions, fnames)
     for region, fname in zip(regions, fnames):
         if isinstance(region, (list, tuple)):
             c, s, e = region
@@ -231,19 +260,20 @@ def concat_variant_files(orig_files, out_file, regions, ref_file, config):
     sample information, so no complex merging needed. Handles both plain text
     and bgzipped/tabix indexed outputs.
 
-    Falls back to slower CombineVariants if fails due to GATK stringency issues.
+    Falls back to bcftools concat if fails due to GATK stringency issues.
     """
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
-            sorted_files = _sort_by_region(orig_files, regions, ref_file, config)
-            exist_files = [x for x in sorted_files if os.path.exists(x)]
-            ready_files = run_multicore(p_bgzip_and_index, [[x, config] for x in exist_files], config)
-            input_file_list = "%s-files.list" % utils.splitext_plus(out_file)[0]
-            with open(input_file_list, "w") as out_handle:
-                for fname in ready_files:
-                    out_handle.write(fname + "\n")
+        sorted_files = _sort_by_region(orig_files, regions, ref_file, config)
+        exist_files = [x for x in sorted_files if os.path.exists(x)]
+        ready_files = run_multicore(p_bgzip_and_index, [[x, config] for x in exist_files], config)
+        input_file_list = "%s-files.list" % utils.splitext_plus(out_file)[0]
+        with open(input_file_list, "w") as out_handle:
+            for fname in ready_files:
+                out_handle.write(fname + "\n")
+        failed = False
+        with file_transaction(config, out_file) as tx_out_file:
             params = ["org.broadinstitute.gatk.tools.CatVariants",
-                      "-R" , ref_file,
+                      "-R", ref_file,
                       "-V", input_file_list,
                       "-out", tx_out_file,
                       "-assumeSorted"]
@@ -252,10 +282,27 @@ def concat_variant_files(orig_files, out_file, regions, ref_file, config):
             try:
                 do.run(cmd, "Concat variant files", log_error=False)
             except subprocess.CalledProcessError, msg:
-                if str(msg).find("We require all VCFs to have complete VCF headers"):
-                    return combine_variant_files(orig_files, out_file, ref_file, config)
+                if ("We require all VCFs to have complete VCF headers" in str(msg) or
+                      "Features added out of order" in str(msg)):
+                    os.remove(tx_out_file)
+                    failed = True
                 else:
                     raise
+        if failed:
+            return concat_variant_files_bcftools(input_file_list, out_file, ref_file, config)
+    if out_file.endswith(".gz"):
+        bgzip_and_index(out_file, config)
+    return out_file
+
+def concat_variant_files_bcftools(in_list, out_file, ref_file, config):
+    """Concatenate variant files using bcftools concat.
+    """
+    if not utils.file_exists(out_file):
+        with file_transaction(config, out_file) as tx_out_file:
+            bcftools = config_utils.get_program("bcftools", config)
+            output_type = "z" if out_file.endswith(".gz") else "v"
+            cmd = "{bcftools} concat --allow-overlaps -O {output_type} --file-list {in_list} -o {tx_out_file}"
+            do.run(cmd.format(**locals()), "bcftools concat variants")
     if out_file.endswith(".gz"):
         bgzip_and_index(out_file, config)
     return out_file
@@ -273,7 +320,7 @@ def combine_variant_files(orig_files, out_file, ref_file, config,
         in_pipeline = True
         orig_files = orig_files[file_key]
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             exist_files = [x for x in orig_files if os.path.exists(x)]
             ready_files = run_multicore(p_bgzip_and_index, [[x, config] for x in exist_files], config)
             params = ["-T", "CombineVariants",
@@ -351,15 +398,18 @@ def move_vcf(orig_file, new_file):
         if os.path.exists(to_move):
             shutil.move(to_move, new_file + ext)
 
-def bgzip_and_index(in_file, config, remove_orig=True):
+def bgzip_and_index(in_file, config, remove_orig=True, prep_cmd=""):
     """bgzip and tabix index an input file, handling VCF and BED.
     """
     out_file = in_file if in_file.endswith(".gz") else in_file + ".gz"
     if not utils.file_exists(out_file) or not os.path.lexists(out_file):
         assert not in_file == out_file, "Input file is bgzipped but not found: %s" % in_file
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             bgzip = tools.get_bgzip_cmd(config)
-            cmd = "{bgzip} -c {in_file} > {tx_out_file}"
+            if prep_cmd:
+                cmd = "cat {in_file} | {prep_cmd} | {bgzip} -c > {tx_out_file}"
+            else:
+                cmd = "{bgzip} -c {in_file} > {tx_out_file}"
             try:
                 do.run(cmd.format(**locals()), "bgzip %s" % os.path.basename(in_file))
             except subprocess.CalledProcessError:
@@ -398,11 +448,7 @@ def tabix_index(in_file, config, preset=None):
     in_file = os.path.abspath(in_file)
     out_file = in_file + ".tbi"
     if not utils.file_exists(out_file) or not utils.file_uptodate(out_file, in_file):
-        try:
-            os.remove(out_file)
-        except OSError:
-            pass
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             tabix = tools.get_tabix_cmd(config)
             tx_in_file = os.path.splitext(tx_out_file)[0]
             utils.symlink_plus(in_file, tx_in_file)
